@@ -60,6 +60,7 @@ class URLTestCaseMixin:
 
 class LoginRequiredTestCaseMixin:
     extra_user_fields = {}
+    expected_status_code = 200
 
     @classmethod
     def setUpTestData(cls):
@@ -84,7 +85,7 @@ class LoginRequiredTestCaseMixin:
         url = self.get_url()
 
         resp = self.client.get(url)
-        assert resp.status_code == 200
+        assert resp.status_code == self.expected_status_code
 
         self.client.logout()
 
