@@ -1,13 +1,25 @@
 import json
+from typing import Optional
 
 from graphql_jwt.shortcuts import get_token
 
 
 class GraphQLMixin:
-    def execute(self, query, variables=None, as_user=None, files=None):
+    def execute(
+        self,
+        query: str,
+        variables: Optional[dict] = None,
+        as_user: Optional = None,
+        files: Optional[dict] = None,
+        extra_token_data: Optional[dict] = None,
+    ):
         headers = {}
         if as_user:
-            headers["HTTP_AUTHORIZATION"] = f"JWT {get_token(as_user)}"
+            if extra_token_data is None:
+                extra_token_data = {}
+            headers[
+                "HTTP_AUTHORIZATION"
+            ] = f"JWT {get_token(as_user, **extra_token_data)}"
 
         data = {
             "operations": json.dumps({"query": query, "variables": variables or {}})
